@@ -6,12 +6,8 @@ import warnings
 
 import numpy as np
 
-from .. import coding, conventions
-from ..core import indexing
-from ..core.pycompat import integer_types
-from ..core.utils import FrozenDict, HiddenKeyDict, close_on_error, module_available
-from ..core.variable import Variable
-from .common import (
+from xarray import coding, conventions
+from xarray.backends.common import (
     BACKEND_ENTRYPOINTS,
     AbstractWritableDataStore,
     BackendArray,
@@ -19,7 +15,16 @@ from .common import (
     _encode_variable_name,
     _normalize_path,
 )
-from .store import StoreBackendEntrypoint
+from xarray.backends.store import StoreBackendEntrypoint
+from xarray.core import indexing
+from xarray.core.pycompat import integer_types
+from xarray.core.utils import (
+    FrozenDict,
+    HiddenKeyDict,
+    close_on_error,
+    module_available,
+)
+from xarray.core.variable import Variable
 
 # need some special secret attributes to tell us the dimensions
 DIMENSION_KEY = "_ARRAY_DIMENSIONS"
@@ -791,7 +796,7 @@ def open_zarr(
     ----------
     http://zarr.readthedocs.io/
     """
-    from .api import open_dataset
+    from xarray.backends.api import open_dataset
 
     if chunks == "auto":
         try:
